@@ -446,7 +446,7 @@ class AnnotationManager(object):
         """
 
         import cv2
-        from ..assets.color_list import color_list
+        color_list = [(159, 2, 98), (95, 32, 219), (222, 92, 189), (56, 233, 120), (23, 180, 100), (78, 69, 20), (97, 202, 39), (65, 179, 135), (163, 159, 219)]
 
         image = image.copy()
 
