@@ -527,5 +527,11 @@ class DataManager(object):
                     ret.append(recs)
             yield ret
 
+    def __mul__(self, number):
+        number = int(number)
+        assert number > 0
+        new_record_list = self.record_list * number
+        return (type(self))(new_record_list, self.class_dict)
+    
     # overwrite operator '+'
     __add__ = merge
