@@ -80,7 +80,7 @@ def to_gray_image(img):
             raise FileNotFoundError(f"file not found {str(img)}")
     elif isinstance(img, np.ndarray):
         if img.ndim == 2:
-            return img
+            return img.copy()
         elif img.ndim == 3:
             return cv2.cvtColor(img, cv2.COLOR_RGB2GRAY)
         else:
